/**
 *
 * This file is part of Tulip (http://tulip.labri.fr)
 *
 * Authors: David Auber and the Tulip development Team
 * from LaBRI, University of Bordeaux
 *
 * Tulip is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *
 * Tulip is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 */

#ifndef SCREENFUNCTION_H
#define SCREENFUNCTION_H

#include "potypes.h"

namespace pocore {
class ScreenFunction {

public:
  virtual ~ScreenFunction() {}
  virtual Vec2f project(const Vec2f &) const = 0;
  virtual Vec2f unproject(const Vec2f &) const = 0;
};
} // namespace pocore
#endif // SCREENFUNCTION_H
